pub enum DataValue {
Null,
String(String),
Bool(bool),
Int(isize),
Float(f64),
List(Vec<DataValue>),
Datetime(DateTime<FixedOffset>),
Map(BTreeMap<String, DataValue>),
}Expand description
This type encapsulates a value and its type.
It is held by AnnotationData alongside a reference to a DataKey, resulting in a key/value pair.
Variants
Null
No value
String(String)
A string value
Bool(bool)
A boolean value
Int(isize)
A numeric integer value
Float(f64)
A numeric floating-point value
List(Vec<DataValue>)
Value is an unordered set The value is an ordered list
Datetime(DateTime<FixedOffset>)
The value is a date/timestamp
Map(BTreeMap<String, DataValue>)
The value is a map
Implementations
Sourceimpl<'a> DataValue
impl<'a> DataValue
Sourcepub fn test(&self, operator: &DataOperator<'a>) -> bool
pub fn test(&self, operator: &DataOperator<'a>) -> bool
This applies a DataOperator to the data value, and returns a boolean if the values passes the constraints posed by the operator.
Note that the DataOperator itself holds the value that is tested against.
Sourcepub fn to_json(&self) -> Result<String, StamError>
pub fn to_json(&self) -> Result<String, StamError>
Writes a datavalue to one STAM JSON string, with appropriate formatting
Sourcepub fn to_json_compact(&self) -> Result<String, StamError>
pub fn to_json_compact(&self) -> Result<String, StamError>
Writes a datavalue to one STAM JSON string, without any indentation