pub struct AnnotationDataSetHandle(/* private fields */);Trait Implementations
Sourceimpl Clone for AnnotationDataSetHandle
impl Clone for AnnotationDataSetHandle
Sourcefn clone(&self) -> AnnotationDataSetHandle
fn clone(&self) -> AnnotationDataSetHandle
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DataSize for AnnotationDataSetHandle
impl DataSize for AnnotationDataSetHandle
Sourceconst IS_DYNAMIC: bool = <u16 as datasize::DataSize>::IS_DYNAMIC
const IS_DYNAMIC: bool = <u16 as datasize::DataSize>::IS_DYNAMIC
If
true, the type has a heap size that can vary at runtime, depending on the actual value.Sourceconst STATIC_HEAP_SIZE: usize = <u16 as datasize::DataSize>::STATIC_HEAP_SIZE
const STATIC_HEAP_SIZE: usize = <u16 as datasize::DataSize>::STATIC_HEAP_SIZE
The amount of space a value of the type always occupies. If
IS_DYNAMIC is false, this is
the total amount of heap memory occupied by the value. Otherwise this is a lower bound.Sourcefn estimate_heap_size(&self) -> usize
fn estimate_heap_size(&self) -> usize
Estimates the size of heap memory taken up by this value. Read more
Sourceimpl Debug for AnnotationDataSetHandle
impl Debug for AnnotationDataSetHandle
Sourceimpl<'bytes, Ctx> Decode<'bytes, Ctx> for AnnotationDataSetHandle
impl<'bytes, Ctx> Decode<'bytes, Ctx> for AnnotationDataSetHandle
Sourceimpl<Ctx> Encode<Ctx> for AnnotationDataSetHandle
impl<Ctx> Encode<Ctx> for AnnotationDataSetHandle
Sourceimpl From<&AnnotationDataSetHandle> for BuildItem<'_, AnnotationDataSet>
impl From<&AnnotationDataSetHandle> for BuildItem<'_, AnnotationDataSet>
Sourcefn from(handle: &AnnotationDataSetHandle) -> Self
fn from(handle: &AnnotationDataSetHandle) -> Self
Converts to this type from the input type.
Sourceimpl From<AnnotationDataSetHandle> for BuildItem<'_, AnnotationDataSet>
impl From<AnnotationDataSetHandle> for BuildItem<'_, AnnotationDataSet>
Sourcefn from(handle: AnnotationDataSetHandle) -> Self
fn from(handle: AnnotationDataSetHandle) -> Self
Converts to this type from the input type.
Sourceimpl Handle for AnnotationDataSetHandle
impl Handle for AnnotationDataSetHandle
Sourceimpl Hash for AnnotationDataSetHandle
impl Hash for AnnotationDataSetHandle
Sourceimpl Ord for AnnotationDataSetHandle
impl Ord for AnnotationDataSetHandle
Sourcefn cmp(&self, other: &AnnotationDataSetHandle) -> Ordering
fn cmp(&self, other: &AnnotationDataSetHandle) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AnnotationDataSetHandle
impl PartialEq for AnnotationDataSetHandle
Sourceimpl PartialOrd for AnnotationDataSetHandle
impl PartialOrd for AnnotationDataSetHandle
Sourceimpl<'a> Request<AnnotationDataSet> for AnnotationDataSetHandle
impl<'a> Request<AnnotationDataSet> for AnnotationDataSetHandle
Sourcefn to_handle<'store, S>(
&self,
_store: &'store S,
) -> Option<AnnotationDataSetHandle>where
S: StoreFor<AnnotationDataSet>,
fn to_handle<'store, S>(
&self,
_store: &'store S,
) -> Option<AnnotationDataSetHandle>where
S: StoreFor<AnnotationDataSet>,
Returns the handle for this item, looking it up in the store
Sourcefn requested_id(&self) -> Option<&str>
fn requested_id(&self) -> Option<&str>
If this type encapsulates an Id, this returns it (borrowed)
Sourcefn requested_id_owned(self) -> Option<String>
fn requested_id_owned(self) -> Option<String>
If this type encapsulates an Id, this returns it (oened)
Sourcefn requested_handle(&self) -> Option<T::HandleType>
fn requested_handle(&self) -> Option<T::HandleType>
If this type encapsulates a handle, this returns it
impl Copy for AnnotationDataSetHandle
impl Eq for AnnotationDataSetHandle
impl StructuralPartialEq for AnnotationDataSetHandle