TestableIterator

Trait TestableIterator 

pub trait TestableIterator: Iterator
where Self: Sized,
{ // Provided method fn test(self) -> bool { ... } }
This iterator implements a simple .test() method that just checks whether an iterator is empty or yields results. It is implemented alongside traits like AnnotationIterator, DataIterator, etc…

Provided Methods

fn test(self) -> bool

Returns true if the iterator has items, false otherwise

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<I> TestableIterator for I
where I: Iterator,